==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/docs/web/docs/Netedit/shortcuts.md <==
---
title: Shortcuts
---

## NETEDIT mode shortcuts

| Shortcut | Network mode | Demand Mode | Data Mode |
|:---:|:---:|:-:|:---:|
| A | <span style="color:orange">Additional mode | <span style="color:orange">Stop Mode | <span style="color:orange">- |
| C | <span style="color:orange">Connection Mode | <span style="color:orange">Person Plan mode | <span style="color:orange">Connection Data Mode |
| D | <span style="color:orange">Delete Mode | <span style="color:orange">Delete Mode | <span style="color:orange">Delete Mode |
| E | <span style="color:orange">Edge Mode | <span style="color:orange">- | <span style="color:orange">Edge Data Mode |
| G | <span style="color:orange">- | <span style="color:orange">Container mode | <span style="color:orange">- |
| H | <span style="color:orange">Prohibition mode | <span style="color:orange">Container Plan mode | <span style="color:orange">- |
| I | <span style="color:orange">Inspect Mode | <span style="color:orange">Inspect Mode | <span style="color:orange">Inspect Mode |
| J | <span style="color:orange">- | <span style="color:orange">- | <span style="color:orange">Junction Data Mode |
| L | <span style="color:orange">- | <span style="color:orange">- | <span style="color:orange">Lane Data Mode |
| M | <span style="color:orange">Move Mode | <span style="color:orange">Move Mode | <span style="color:orange">- |
| P | <span style="color:orange">Polygon Mode | <span style="color:orange">Person Mode | <span style="color:orange">- |
| R | <span style="color:orange">Crossing Mode | <span style="color:orange">Route Mode | <span style="color:orange">Edge Rel Data Mode |
| S | <span style="color:orange">Select Mode | <span style="color:orange">Select Mode | <span style="color:orange">Select Mode |
| T | <span style="color:orange">Traffic Light Mode | <span style="color:orange">Type Mode | - |
| V | <span style="color:orange">- | <span style="color:orange">Vehicle Mode | <span style="color:orange">- |
| W | <span style="color:orange">Wire mode | <span style="color:orange">- | <span style="color:orange">- |
| Z | <span style="color:orange">TAZ Mode | <span style="color:orange">- | <span style="color:orange">TAZ Data Mode |
| F5 | <span style="color:orange">Recompute Network | <span style="color:orange">Recompute Demand | <span style="color:orange">Recompute Data |
| F6 | <span style="color:orange">Clean Junctions | <span style="color:orange">Clean Routes | <span style="color:orange">Clean Data |
| F7 | <span style="color:orange">Join selected junctions | <span style="color:orange">Join Routes | <span style="color:orange">Join Data |
| F8 | <span style="color:orange">Clear invalid crossings | <span style="color:orange">Clear invalid demand elements | <span style="color:orange">clear invalid data elements |

## NETEDIT basic shortcuts

| Shortcut | |
|:---:|:---:|
| ENTER | <span style="color:orange">Accept/create |
| ESC | <span style="color:orange">Abort |
| TAB | <span style="color:orange">Jump to next Element |
| F1 | <span style="color:orange">Online documentation |
| F2 | <span style="color:orange">Supermode Network |
| F3 | <span style="color:orange">Supermode Demand |
| F4 | <span style="color:orange">Supermode Data |
| F9 | <span style="color:orange">Edit viewport |
| F10 | <span style="color:orange">Open Options dialog |
| F11 | <span style="color:orange">Set / Clear front element |
| F12 | <span style="color:orange">About dialog |

## NETEDIT control shortcuts

| Shortcut | |
|:---:|:---:|
| Ctrl + A | <span style="color:orange">Load additional elements |
| Ctrl + B | <span style="color:orange">Load data elements |
| Ctrl + C | <span style="color:orange">Copy |
| Ctrl + D | <span style="color:orange">Load demand elements |
| Ctrl + G | <span style="color:orange">Toggle grid |
| Ctrl + H | <span style="color:orange">Load edge type elements |
| Ctrl + I | <span style="color:orange">Edit visualization |
| Ctrl + J | <span style="color:orange">Show junction shape |
| Ctrl + K | <span style="color:orange">Load traffic lights |
| Ctrl + L | <span style="color:orange">Save plain XML |
| Ctrl + N | <span style="color:orange">New network |
| Ctrl + Q | <span style="color:orange">Close SUMO/NETEDIT |
| Ctrl + R | <span style="color:orange">Reload network |
| Ctrl + S | <span style="color:orange">Save network |
| Ctrl + T | <span style="color:orange">Toggle between SUMO/NETEDIT |
| Ctrl + V | <span style="color:orange">Paste |
| Ctrl + W | <span style="color:orange">Close Net |
| Ctrl + X | <span style="color:orange">Cut |
| Ctrl + Y | <span style="color:orange">Redo |
| Ctrl + Z | <span style="color:orange">Undo |
| Ctrl + F5 | <span style="color:orange">Volatile recomputing |
| Ctrl + F7 | <span style="color:orange">Adjust person plans|

## NETEDIT locate shortcuts

| Shortcut | |
|:---:|:---:|
| Shift + A | <span style="color:orange">Locate Additionals |
| Shift + E | <span style="color:orange">Locate Edges |
| Shift + J | <span style="color:orange">Locate Junctions |
| Shift + L | <span style="color:orange">Locate Polygons |
| Shift + O | <span style="color:orange">Locate POIs |
| Shift + R | <span style="color:orange">Locate Routes |
| Shift + S | <span style="color:orange">Locate Stops |
| Shift + T | <span style="color:orange">Locate TLS |
| Shift + V | <span style="color:orange">Locate Vehicles |

## NETEDIT save elements shortcuts

| Shortcut |  |
|:---:|:---:|
| Control + Shift + A | <span style="color:orange">Save Additional Elements |
| Control + Shift + B | <span style="color:orange">Save Data Elements |
| Control + Shift + D | <span style="color:orange">Save Demand Elements |
| Control + Shift + H | <span style="color:orange">Save Edge Type Elements |
| Control + Shift + K | <span style="color:orange">Save Traffic Lights |
| Control + Shift + N | <span style="color:orange">Save Network |
| Control + Shift + O | <span style="color:orange">New window |
| Control + Shift + R | <span style="color:orange">Force Save Network (Flag) |
| Control + Shift + S | <span style="color:orange">Force Save Additional (Flag) |
| Control + Shift + T | <span style="color:orange">Force Save Demand Elements (Flag) |
| Control + Shift + U | <span style="color:orange">Force Save Data elements (Flag) |
| Control + Shift + F12 | <span style="color:orange">Save Geometry for testing |

## NETEDIT miscellaneous shortcuts

| Shortcut | |
|:---:|:---:|
| Alt + 0-9 | <span style="color:orange">Toggle view / edit checkbox option |
| Shift + TAB | <span style="color:orange">Jump to previous Element |
| Shift + F1 | <span style="color:orange">Copy Edge template |
| Shift + F2 | <span style="color:orange">Set Edge template |
| Shift + F3 | <span style="color:orange">Clear Edge template |
| Shift + F5 | <span style="color:orange">Compute Junction (volatile) |
| Shift + F7 | <span style="color:orange">Adjust Person Plan |
| Shift + F12 | <span style="color:orange">Focus upper element |

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/docs/web/docs/Netedit/shortcuts.md <==
---
title: Shortcuts
---


## NETEDIT view shortcuts

In addition to the standard [sumo-gui shortcuts for moving the view](../sumo-gui.md#keyboard_shortcuts) there is a large number of netdit-specific shortcuts.

| Shortcut | |
|:---:|:---:|
| Ctrl + G | <span style="color:orange">Toggle grid |
| Ctrl + PgUp | <span style="color:orange">Increase grid size |
| Ctrl + PgDown | <span style="color:orange">Shrink grid size |

## NETEDIT mode shortcuts

| Shortcut | Network mode | Demand Mode | Data Mode |
|:---:|:---:|:-:|:---:|
| A | <span style="color:orange">Additional mode | <span style="color:orange">Stop Mode | <span style="color:orange">- |
| C | <span style="color:orange">Connection Mode | <span style="color:orange">Container mode | <span style="color:orange">Connection Data Mode |
| D | <span style="color:orange">Delete Mode | <span style="color:orange">Delete Mode | <span style="color:orange">Delete Mode |
| E | <span style="color:orange">Edge Mode | <span style="color:orange">- | <span style="color:orange">Edge Data Mode |
| G | <span style="color:orange">- | <span style="color:orange">- | <span style="color:orange">- |
| H | <span style="color:orange">Prohibition mode | <span style="color:orange">Container Plan mode | <span style="color:orange">- |
| I | <span style="color:orange">Inspect Mode | <span style="color:orange">Inspect Mode | <span style="color:orange">Inspect Mode |
| J | <span style="color:orange">- | <span style="color:orange">- | <span style="color:orange">Junction Data Mode |
| L | <span style="color:orange">- | <span style="color:orange"> Person plan mode | <span style="color:orange">Lane Data Mode |
| M | <span style="color:orange">Move Mode | <span style="color:orange">Move Mode | <span style="color:orange">- |
| P | <span style="color:orange">Polygon Mode | <span style="color:orange">Person Mode | <span style="color:orange">- |
| R | <span style="color:orange">Crossing Mode | <span style="color:orange">Route Mode | <span style="color:orange">Edge Rel Data Mode |
| S | <span style="color:orange">Select Mode | <span style="color:orange">Select Mode | <span style="color:orange">Select Mode |
| T | <span style="color:orange">Traffic Light Mode | <span style="color:orange">Type Mode | - |
| V | <span style="color:orange">- | <span style="color:orange">Vehicle Mode | <span style="color:orange">- |
| W | <span style="color:orange">Wire mode | <span style="color:orange">- | <span style="color:orange">- |
| Z | <span style="color:orange">TAZ Mode | <span style="color:orange">- | <span style="color:orange">TAZ Data Mode |
| F5 | <span style="color:orange">Recompute Network | <span style="color:orange">Recompute Demand | <span style="color:orange">Recompute Data |
| F6 | <span style="color:orange">Clean Junctions | <span style="color:orange">Clean Routes | <span style="color:orange">Clean Data |
| F7 | <span style="color:orange">Join selected junctions | <span style="color:orange">Join Routes | <span style="color:orange">Join Data |
| F8 | <span style="color:orange">Clear invalid crossings | <span style="color:orange">Clear invalid demand elements | <span style="color:orange">clear invalid data elements |

## NETEDIT basic shortcuts

| Shortcut | |
|:---:|:---:|
| ENTER | <span style="color:orange">Accept/create |
| ESC | <span style="color:orange">Abort |
| TAB | <span style="color:orange">Jump to next Element |
| F1 | <span style="color:orange">Online documentation |
| F2 | <span style="color:orange">Supermode Network |
| F3 | <span style="color:orange">Supermode Demand |
| F4 | <span style="color:orange">Supermode Data |
| F9 | <span style="color:orange">Visualization settings |
| F10 | <span style="color:orange">Open Options dialog |
| F11 | <span style="color:orange">Set / Clear front element |
| F12 | <span style="color:orange">About dialog |

## NETEDIT control shortcuts

| Shortcut | |
|:---:|:---:|
| Ctrl + A | <span style="color:orange">Load additional elements |
| Ctrl + B | <span style="color:orange">Load data elements |
| Ctrl + C | <span style="color:orange">Copy |
| Ctrl + D | <span style="color:orange">Load demand elements |
| Ctrl + H | <span style="color:orange">Load edge type elements |
| Ctrl + I | <span style="color:orange">Edit view port |
| Ctrl + J | <span style="color:orange">Show junction shape |
| Ctrl + K | <span style="color:orange">Load traffic lights |
| Ctrl + L | <span style="color:orange">Save plain XML |
| Ctrl + N | <span style="color:orange">New network |
| Ctrl + Q | <span style="color:orange">Close SUMO/NETEDIT |
| Ctrl + R | <span style="color:orange">Reload network |
| Ctrl + S | <span style="color:orange">Save network |
| Ctrl + T | <span style="color:orange">Toggle between SUMO/NETEDIT |
| Ctrl + V | <span style="color:orange">Paste |
| Ctrl + W | <span style="color:orange">Close Net |
| Ctrl + X | <span style="color:orange">Cut |
| Ctrl + Y | <span style="color:orange">Redo |
| Ctrl + Z | <span style="color:orange">Undo |
| Ctrl + F5 | <span style="color:orange">Volatile recomputing |
| Ctrl + F7 | <span style="color:orange">Adjust person plans|

## NETEDIT locate shortcuts

| Shortcut | |
|:---:|:---:|
| Shift + A | <span style="color:orange">Locate Additionals |
| Shift + E | <span style="color:orange">Locate Edges |
| Shift + J | <span style="color:orange">Locate Junctions |
| Shift + L | <span style="color:orange">Locate Polygons |
| Shift + O | <span style="color:orange">Locate POIs |
| Shift + R | <span style="color:orange">Locate Routes |
| Shift + S | <span style="color:orange">Locate Stops |
| Shift + T | <span style="color:orange">Locate TLS |
| Shift + V | <span style="color:orange">Locate Vehicles |

## NETEDIT save elements shortcuts

| Shortcut |  |
|:---:|:---:|
| Control + Shift + A | <span style="color:orange">Save Additional Elements |
| Control + Shift + B | <span style="color:orange">Save Data Elements |
| Control + Shift + D | <span style="color:orange">Save Demand Elements |
| Control + Shift + H | <span style="color:orange">Save Edge Type Elements |
| Control + Shift + K | <span style="color:orange">Save Traffic Lights |
| Control + Shift + N | <span style="color:orange">Save Network |
| Control + Shift + O | <span style="color:orange">New window |
| Control + Shift + R | <span style="color:orange">Force Save Network (Flag) |
| Control + Shift + S | <span style="color:orange">Force Save Additional (Flag) |
| Control + Shift + T | <span style="color:orange">Force Save Demand Elements (Flag) |
| Control + Shift + U | <span style="color:orange">Force Save Data elements (Flag) |
| Control + Shift + F12 | <span style="color:orange">Save Geometry for testing |

## NETEDIT miscellaneous shortcuts

| Shortcut | |
|:---:|:---:|
| Alt + 0-9 | <span style="color:orange">Toggle view / edit checkbox option |
| Shift + TAB | <span style="color:orange">Jump to previous Element |
| Shift + F1 | <span style="color:orange">Copy Edge template |
| Shift + F2 | <span style="color:orange">Set Edge template |
| Shift + F3 | <span style="color:orange">Clear Edge template |
| Shift + F5 | <span style="color:orange">Compute Junction (volatile) |
| Shift + F7 | <span style="color:orange">Adjust Person Plan |
| Shift + F12 | <span style="color:orange">Focus upper element |
